==> common-dto-4.2-sources.jar: fr/ird/observe/spi/context/ReferentialDtoContext.java <==
package fr.ird.observe.spi.context;

/*-
 * #%L
 * ObServe Toolkit :: Common Dto
 * %%
 * Copyright (C) 2017 - 2018 IRD, Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ird.observe.binder.referential.ReferentialDtoReferenceBinder;
import fr.ird.observe.dto.reference.DtoReferenceDefinition;
import fr.ird.observe.dto.reference.ReferentialDtoReference;
import fr.ird.observe.dto.referential.ReferentialDto;
import fr.ird.observe.dto.referential.ReferentialLocale;
import fr.ird.observe.spi.initializer.DtoReferencesInitializerSupport;

/**
 * Created by tchemit on 03/09/17.
 *
 * @author Tony Chemit - dev@tchemit.fr
 */
@SuppressWarnings("unchecked")
public class ReferentialDtoContext<D extends ReferentialDto, R extends ReferentialDtoReference<D, R>> {

    private final Class<D> dtoType;
    private final Class<R> referenceType;
    private final ReferentialDtoReferenceBinder<D, R> referenceBinder;
    private final DtoReferenceDefinition<D, R> referenceDefinition;

    public ReferentialDtoContext(Class<D> dtoType, DtoReferencesInitializerSupport modelHelper) {
        this.dtoType = dtoType;
        this.referenceType = modelHelper.getDtoToReferenceClassMapping().forReferential(dtoType);
        this.referenceBinder = modelHelper.getReferentialBinders().get(dtoType);
        this.referenceDefinition = modelHelper.getReferentialReferenceSetDefinition().get(dtoType);
    }

    public Class<D> toDtoType() {
        return dtoType;
    }

    public <RR extends ReferentialDtoReference<D, RR>> Class<RR> toReferenceType() {
        return (Class<RR>) referenceType;
    }

    public <RR extends ReferentialDtoReference<D, RR>> ReferentialDtoReferenceBinder<D, RR> toReferenceBinder() {
        return (ReferentialDtoReferenceBinder<D, RR>) referenceBinder;
    }

    public <RR extends ReferentialDtoReference<D, RR>> DtoReferenceDefinition<D, RR> toReferenceDefinition() {
        return (DtoReferenceDefinition<D, RR>) referenceDefinition;
    }

    public <RR extends ReferentialDtoReference<D, RR>> RR toReference(ReferentialLocale referentialLocale, D dto) {
        return (RR) referenceBinder.toReference(referentialLocale, dto);
    }
}

==> common-dto-4.13-sources.jar: fr/ird/observe/spi/context/ReferentialDtoContext.java <==
package fr.ird.observe.spi.context;

/*-
 * #%L
 * ObServe Toolkit :: Common Dto
 * %%
 * Copyright (C) 2017 - 2019 IRD, Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ird.observe.binder.referential.ReferentialDtoReferenceBinder;
import fr.ird.observe.dto.reference.DtoReferenceDefinition;
import fr.ird.observe.dto.reference.ReferentialDtoReference;
import fr.ird.observe.dto.referential.ReferentialDto;
import fr.ird.observe.dto.referential.ReferentialLocale;
import fr.ird.observe.spi.initializer.DtoReferencesInitializerSupport;

/**
 * Created by tchemit on 03/09/17.
 *
 * @author Tony Chemit - dev@tchemit.fr
 */
@SuppressWarnings("unchecked")
public class ReferentialDtoContext<D extends ReferentialDto, R extends ReferentialDtoReference<D, R>> implements DtoContext<D,R> {

    private final Class<D> dtoType;
    private final Class<R> referenceType;
    private final ReferentialDtoReferenceBinder<D, R> referenceBinder;
    private final DtoReferenceDefinition<D, R> referenceDefinition;

    public ReferentialDtoContext(Class<D> dtoType, DtoReferencesInitializerSupport modelHelper) {
        this.dtoType = dtoType;
        this.referenceType = modelHelper.getDtoToReferenceClassMapping().forReferential(dtoType);
        this.referenceBinder = modelHelper.getReferentialBinders().get(dtoType);
        this.referenceDefinition = modelHelper.getReferentialReferenceSetDefinition().get(dtoType);
    }

    @Override
    public Class<D> toDtoType() {
        return dtoType;
    }

    @Override
    public Class<R> toReferenceType() {
        return referenceType;
    }

    @Override
    public ReferentialDtoReferenceBinder<D, R> toReferenceBinder() {
        return referenceBinder;
    }

    @Override
    public DtoReferenceDefinition<D, R> toReferenceDefinition() {
        return referenceDefinition;
    }

    @Override
    public R toReference(ReferentialLocale referentialLocale, D dto) {
        return referenceBinder.toReference(referentialLocale, dto);
    }
}
